@@ -219,6 +219,9 @@ bool_t libnfs_zdr_opaque(ZDR *zdrs, char *objp, uint32_t size)
 	case ZDR_ENCODE:
 		memcpy(&zdrs->buf[zdrs->pos], objp, size);
 		zdrs->pos += size;
+		if (zdrs->pos & 3) {
+			memset(&zdrs->buf[zdrs->pos], 0x00, 4 - (zdrs->pos & 3));
+		}
 		zdrs->pos = (zdrs->pos + 3) & ~3;
 		return TRUE;
 	case ZDR_DECODE:
@@ -476,10 +479,12 @@ struct AUTH *libnfs_authunix_create(char *host, uint32_t uid, uint32_t gid, uint
 
 	size = 4 + 4 + ((strlen(host) + 3) & ~3) + 4 + 4 + 4 + len * 4;
 	auth = malloc(sizeof(struct AUTH));
+	memset(auth, 0x00, sizeof(struct AUTH));
 	auth->ah_cred.oa_flavor = AUTH_UNIX;
 	auth->ah_cred.oa_length = size;
 	auth->ah_cred.oa_base = malloc(size);
 
+	memset(auth->ah_cred.oa_base, 0x00, size);
 	buf = (uint32_t *)auth->ah_cred.oa_base;
 	idx = 0;
 	buf[idx++] = htonl(time(NULL));
